import { Vector } from "./EM";
import { DBSchema, IDBPDatabase } from 'idb/with-async-ittr';
export declare enum PredictDatabaseStatus {
    empty = 0,
    collecting = 1,
    computing = 2,
    finished = 3
}
interface PredictHeightDB extends DBSchema {
    'dynamic-height-list': {
        value: {
            weight: Vector;
            height: number;
        };
        key: string;
    };
}
declare type ListenerCallbackType = (allList: Vector[], itemToHeightMap: Record<string, number>) => void;
export default class PredictDatabase {
    weight: Map<keyof Vector, number>;
    DBStatus: PredictDatabaseStatus;
    waitToPredictList: Vector[];
    listeners: ((allList: Vector[], itemToHeightMap: Record<string, number>) => void)[];
    db: IDBPDatabase<PredictHeightDB> | null;
    capacity: number;
    constructor(capacity: number);
    initDB(): Promise<void>;
    initWeight(weight: Map<keyof Vector, number>): void;
    restoreFromCache(): void;
    initWaitToPredictList(list: Vector[]): Promise<void>;
    clearAllData(): void;
    addListener(callback: ListenerCallbackType): void;
    removeListener(callback: ListenerCallbackType): void;
    isReadyToPredict(): Promise<boolean>;
    addSample(index: number, height: number): Promise<void>;
    predict(centroids: Vector[], centroidsHeight: number[]): number[];
}
export {};
